@@ -42,8 +42,9 @@
 #include "lookupcertificatescommand.h"
 #include "checksumverifyfilescommand.h"
 
-#include "models/keycache.h"
-#include "utils/classify.h"
+#include <Libkleo/KeyCache>
+#include <Libkleo/Classify>
+
 
 #include <view/tabwidget.h>
 
