@@ -65,8 +65,10 @@ private:
     QCheckBox *mQuickEncryptCB,
               *mQuickSignCB,
               *mPGPFileExtCB,
-              *mAutoDecryptVerifyCB;
-    QComboBox *mChecksumDefinitionCB;
+              *mAutoDecryptVerifyCB,
+              *mASCIIArmorCB;
+    QComboBox *mChecksumDefinitionCB,
+              *mArchiveDefinitionCB;
 };
 
 }
