@@ -48,7 +48,7 @@
 #include <QPushButton>
 
 #include <vector>
-#include <boost/shared_ptr.hpp>
+#include <cassert>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -59,8 +59,8 @@ using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace Kleo::Crypto::Gui;
 
-DecryptVerifyFilesDialog::DecryptVerifyFilesDialog(const boost::shared_ptr<TaskCollection> &coll, QWidget *parent)
-    : QDialog(parent), m_tasks(coll), m_buttonBox(new QDialogButtonBox)
+DecryptVerifyFilesDialog::DecryptVerifyFilesDialog(const std::shared_ptr<TaskCollection> &coll, QWidget *parent)
+    : QDialog(parent), m_tasks(coll), m_saveButton(QDialogButtonBox::NoButton), m_buttonBox(new QDialogButtonBox)
 {
     readConfig();
     auto vLay = new QVBoxLayout(this);
@@ -97,7 +97,7 @@ DecryptVerifyFilesDialog::DecryptVerifyFilesDialog(const boost::shared_ptr<TaskC
     layout()->addWidget(m_buttonBox);
 
     bool hasOutputs = false;
-    Q_FOREACH (const boost::shared_ptr<Task> t, coll->tasks()) {
+    Q_FOREACH (const std::shared_ptr<Task> t, coll->tasks()) {
         if (!qobject_cast<VerifyDetachedTask *>(t.get())) {
             hasOutputs = true;
             break;
@@ -105,19 +105,20 @@ DecryptVerifyFilesDialog::DecryptVerifyFilesDialog(const boost::shared_ptr<TaskC
     }
     if (hasOutputs) {
         setWindowTitle(i18n("Decrypt/Verify Files"));
-        m_okButton = QDialogButtonBox::SaveAll;
+        m_saveButton = QDialogButtonBox::SaveAll;
         m_buttonBox->addButton(QDialogButtonBox::Discard);
         connect(m_buttonBox, &QDialogButtonBox::accepted, this, &DecryptVerifyFilesDialog::checkAccept);
     } else {
         outLabel->setVisible(false);
         m_outputLocationFNR->setVisible(false);
         setWindowTitle(i18n("Verify Files"));
-        m_okButton = QDialogButtonBox::Ok;
         m_buttonBox->addButton(QDialogButtonBox::Close);
-        connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accepted);
+        connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    }
+    if (m_saveButton) {
+        m_buttonBox->addButton(m_saveButton);
+        m_buttonBox->button(m_saveButton)->setEnabled(false);
     }
-    m_buttonBox->addButton(m_okButton);
-    m_buttonBox->button(m_okButton)->setEnabled(false);
 }
 
 DecryptVerifyFilesDialog::~DecryptVerifyFilesDialog()
@@ -140,10 +141,15 @@ void DecryptVerifyFilesDialog::allDone()
             m_progressLabelByTag.value(i)->setText(i18n("All operations completed."));
         }
     }
-    m_buttonBox->button(m_okButton)->setEnabled(true);
+    if (m_saveButton != QDialogButtonBox::NoButton) {
+        m_buttonBox->button(m_saveButton)->setEnabled(true);
+    } else {
+        m_buttonBox->removeButton(m_buttonBox->button(QDialogButtonBox::Close));
+        m_buttonBox->addButton(QDialogButtonBox::Ok);
+    }
 }
 
-void DecryptVerifyFilesDialog::started(const boost::shared_ptr<Task> &task)
+void DecryptVerifyFilesDialog::started(const std::shared_ptr<Task> &task)
 {
     Q_ASSERT(task);
     const auto tag = task->tag();
