@@ -40,9 +40,9 @@
 #include <utils/auditlog.h>
 
 #include <Libkleo/Stl_Util>
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/SignJob>
+
+#include <QGpgME/Protocol>
+#include <QGpgME/SignJob>
 
 #include <gpgme++/signingresult.h>
 #include <gpgme++/key.h>
@@ -52,12 +52,11 @@
 #include <QPointer>
 #include <QTextDocument> // for Qt::escape
 
-#include <boost/bind.hpp>
-#include <boost/mem_fn.hpp>
+#include <algorithm>
+#include <functional>
 
 using namespace Kleo;
 using namespace Kleo::Crypto;
-using namespace boost;
 using namespace GpgME;
 
 namespace
@@ -103,21 +102,21 @@ public:
     explicit Private(SignEMailTask *qq);
 
 private:
-    std::unique_ptr<Kleo::SignJob> createJob(GpgME::Protocol proto);
+    std::unique_ptr<QGpgME::SignJob> createJob(GpgME::Protocol proto);
 
 private:
     void slotResult(const SigningResult &);
 
 private:
-    shared_ptr<Input> input;
-    shared_ptr<Output> output;
+    std::shared_ptr<Input> input;
+    std::shared_ptr<Output> output;
     std::vector<Key> signers;
     bool detached;
     bool clearsign;
 
     QString micAlg;
 
-    QPointer<Kleo::SignJob> job;
+    QPointer<QGpgME::SignJob> job;
 };
 
 SignEMailTask::Private::Private(SignEMailTask *qq)
@@ -141,14 +140,14 @@ SignEMailTask::SignEMailTask(QObject *p)
 
 SignEMailTask::~SignEMailTask() {}
 
-void SignEMailTask::setInput(const shared_ptr<Input> &input)
+void SignEMailTask::setInput(const std::shared_ptr<Input> &input)
 {
     kleo_assert(!d->job);
     kleo_assert(input);
     d->input = input;
 }
 
-void SignEMailTask::setOutput(const shared_ptr<Output> &output)
+void SignEMailTask::setOutput(const std::shared_ptr<Output> &output)
 {
     kleo_assert(!d->job);
     kleo_assert(output);
@@ -159,7 +158,7 @@ void SignEMailTask::setSigners(const std::vector<Key> &signers)
 {
     kleo_assert(!d->job);
     kleo_assert(!signers.empty());
-    kleo_assert(kdtools::none_of(signers, mem_fn(&Key::isNull)));
+    kleo_assert(std::none_of(signers.cbegin(), signers.cend(), std::mem_fn(&Key::isNull)));
     d->signers = signers;
 }
 
@@ -202,7 +201,7 @@ void SignEMailTask::doStart()
 
     d->micAlg.clear();
 
-    std::unique_ptr<Kleo::SignJob> job = d->createJob(protocol());
+    std::unique_ptr<QGpgME::SignJob> job = d->createJob(protocol());
     kleo_assert(job.get());
 
     job->start(d->signers,
@@ -219,12 +218,12 @@ void SignEMailTask::cancel()
     }
 }
 
-std::unique_ptr<Kleo::SignJob> SignEMailTask::Private::createJob(GpgME::Protocol proto)
+std::unique_ptr<QGpgME::SignJob> SignEMailTask::Private::createJob(GpgME::Protocol proto)
 {
-    const CryptoBackend::Protocol *const backend = CryptoBackendFactory::instance()->protocol(proto);
+    const QGpgME::Protocol *const backend = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     kleo_assert(backend);
     bool shouldArmor = (proto == OpenPGP || q->asciiArmor()) && !output->binaryOpt();
-    std::unique_ptr<Kleo::SignJob> signJob(backend->signJob(/*armor=*/ shouldArmor, /*textmode=*/false));
+    std::unique_ptr<QGpgME::SignJob> signJob(backend->signJob(/*armor=*/ shouldArmor, /*textmode=*/false));
     kleo_assert(signJob.get());
     if (proto == CMS && !q->asciiArmor() && !output->binaryOpt()) {
         signJob->setOutputIsBase64Encoded(true);
@@ -240,15 +239,11 @@ static QString collect_micalgs(const GpgME::SigningResult &result, GpgME::Protoc
 {
     const std::vector<GpgME::CreatedSignature> css = result.createdSignatures();
     QStringList micalgs;
-#ifndef DASHBOT_HAS_STABLE_COMPILER
-    Q_FOREACH (const GpgME::CreatedSignature &sig, css) {
-        micalgs.push_back(QString::fromLatin1(sig.hashAlgorithmAsString()).toLower());
-    }
-#else
     std::transform(css.begin(), css.end(),
                    std::back_inserter(micalgs),
-                   boost::bind(&QString::toLower, boost::bind(&QString::fromLatin1, boost::bind(&GpgME::CreatedSignature::hashAlgorithmAsString, _1), -1)));
-#endif
+                   [](const GpgME::CreatedSignature &sig) {
+                       return QString::fromLatin1(sig.hashAlgorithmAsString()).toLower();
+                   });
     if (proto == GpgME::OpenPGP)
         for (QStringList::iterator it = micalgs.begin(), end = micalgs.end(); it != end; ++it) {
             it->prepend(QStringLiteral("pgp-"));
@@ -260,14 +255,14 @@ static QString collect_micalgs(const GpgME::SigningResult &result, GpgME::Protoc
 
 void SignEMailTask::Private::slotResult(const SigningResult &result)
 {
-    const Job *const job = qobject_cast<const Job *>(q->sender());
+    const QGpgME::Job *const job = qobject_cast<const QGpgME::Job *>(q->sender());
     if (result.error().code()) {
         output->cancel();
     } else {
         output->finalize();
         micAlg = collect_micalgs(result, q->protocol());
     }
-    q->emitResult(shared_ptr<Result>(new SignEMailResult(result, AuditLog::fromJob(job))));
+    q->emitResult(std::shared_ptr<Result>(new SignEMailResult(result, AuditLog::fromJob(job))));
 }
 
 QString SignEMailTask::micAlg() const
