@@ -37,17 +37,21 @@
 #include "signencryptfilestask.h"
 #include "certificateresolver.h"
 
-#include <crypto/gui/signencryptfileswizard.h>
-#include <crypto/taskcollection.h>
+#include "crypto/gui/signencryptfileswizard.h"
+#include "crypto/taskcollection.h"
 
-#include <utils/input.h>
-#include <utils/output.h>
-#include <utils/classify.h>
-#include <utils/kleo_assert.h>
-#include <utils/archivedefinition.h>
+#include "fileoperationspreferences.h"
+
+#include "utils/input.h"
+#include "utils/output.h"
+#include "utils/kleo_assert.h"
+#include "utils/archivedefinition.h"
+#include "utils/path-helper.h"
+
+#include "fileoperationspreferences.h"
 
-#include <Libkleo/Stl_Util>
 #include <Libkleo/Exception>
+#include <Libkleo/Classify>
 
 #include <kmime/kmime_header_parsing.h>
 
@@ -57,33 +61,13 @@
 #include <QPointer>
 #include <QTimer>
 #include <QFileInfo>
-
-#include <boost/bind.hpp>
+#include <QDir>
 
 using namespace Kleo;
 using namespace Kleo::Crypto;
-using namespace Kleo::Crypto::Gui;
-using namespace boost;
 using namespace GpgME;
 using namespace KMime::Types;
 
-namespace
-{
-
-struct is_dir : std::unary_function<QString, bool> {
-    bool operator()(const QString &file) const
-    {
-        return QFileInfo(file).isDir();
-    }
-};
-
-}
-
-static bool contains_dir(const QStringList &files)
-{
-    return kdtools::any(files, is_dir());
-}
-
 class SignEncryptFilesController::Private
 {
     friend class ::Kleo::Crypto::SignEncryptFilesController;
@@ -108,13 +92,13 @@ private:
     }
 
     void schedule();
-    shared_ptr<SignEncryptFilesTask> takeRunnable(GpgME::Protocol proto);
+    std::shared_ptr<SignEncryptFilesTask> takeRunnable(GpgME::Protocol proto);
 
     static void assertValidOperation(unsigned int);
     static QString titleForOperation(unsigned int op);
 private:
-    std::vector< shared_ptr<SignEncryptFilesTask> > runnable, completed;
-    shared_ptr<SignEncryptFilesTask> cms, openpgp;
+    std::vector< std::shared_ptr<SignEncryptFilesTask> > runnable, completed;
+    std::shared_ptr<SignEncryptFilesTask> cms, openpgp;
     QPointer<SignEncryptFilesWizard> wizard;
     QStringList files;
     unsigned int operation;
@@ -176,7 +160,7 @@ SignEncryptFilesController::SignEncryptFilesController(QObject *p)
 
 }
 
-SignEncryptFilesController::SignEncryptFilesController(const shared_ptr<const ExecutionContext> &ctx, QObject *p)
+SignEncryptFilesController::SignEncryptFilesController(const std::shared_ptr<const ExecutionContext> &ctx, QObject *p)
     : Controller(ctx, p), d(new Private(this))
 {
 
@@ -197,7 +181,6 @@ void SignEncryptFilesController::setProtocol(Protocol proto)
                 d->protocol == proto);
     d->protocol = proto;
     d->ensureWizardCreated();
-    d->wizard->setPresetProtocol(proto);
 }
 
 Protocol SignEncryptFilesController::protocol() const
@@ -223,9 +206,6 @@ void SignEncryptFilesController::Private::assertValidOperation(unsigned int op)
 void SignEncryptFilesController::setOperationMode(unsigned int mode)
 {
     Private::assertValidOperation(mode);
-    if (contains_dir(d->files)) {
-        mode = (mode & ~ArchiveMask) | ArchiveForced;
-    }
     d->operation = mode;
     d->updateWizardMode();
 }
@@ -264,16 +244,7 @@ void SignEncryptFilesController::Private::updateWizardMode()
         }
     }
 
-    if (archOp == ArchiveDisallowed) {
-        wizard->setCreateArchivePreset(false);
-        wizard->setCreateArchiveUserMutable(false);
-    } else if (archOp == ArchiveForced) {
-        wizard->setCreateArchiveUserMutable(false);
-        wizard->setCreateArchivePreset(true);
-    } else {
-        wizard->setCreateArchiveUserMutable(true);
-        wizard->setCreateArchivePreset(false);
-    }
+    wizard->setArchiveForced(archOp == ArchiveForced);
 }
 
 unsigned int SignEncryptFilesController::operationMode() const
@@ -281,15 +252,80 @@ unsigned int SignEncryptFilesController::operationMode() const
     return d->operation;
 }
 
+static const char *extension(bool pgp, bool sign, bool encrypt, bool ascii, bool detached)
+{
+    unsigned int cls = pgp ? Class::OpenPGP : Class::CMS;
+    if (encrypt) {
+        cls |= Class::CipherText;
+    } else if (sign) {
+        cls |= detached ? Class::DetachedSignature : Class::OpaqueSignature;
+    }
+    cls |= ascii ? Class::Ascii : Class::Binary;
+    const bool usePGPFileExt = FileOperationsPreferences().usePGPFileExt();
+    if (const char *const ext = outputFileExtension(cls, usePGPFileExt)) {
+        return ext;
+    } else {
+        return "out";
+    }
+}
+
+static std::shared_ptr<ArchiveDefinition> getDefaultAd()
+{
+    std::vector<std::shared_ptr<ArchiveDefinition> > ads = ArchiveDefinition::getArchiveDefinitions();
+    assert(!ads.empty());
+    std::shared_ptr<ArchiveDefinition> ad = ads.front();
+    const FileOperationsPreferences prefs;
+    Q_FOREACH (const std::shared_ptr<ArchiveDefinition> toCheck, ads) {
+        if (toCheck->id() == prefs.archiveCommand()) {
+            ad = toCheck;
+            break;
+        }
+    }
+    return ad;
+}
+
+static QMap <int, QString> buildOutputNames(const QStringList &files, const bool archive)
+{
+    QMap <int, QString> nameMap;
+
+    // Build the default names for the wizard.
+    QString baseNameCms;
+    QString baseNamePgp;
+    const QFileInfo firstFile(files.first());
+    if (archive) {
+        QString baseName;
+        baseName = QDir(heuristicBaseDirectory(files)).absoluteFilePath(files.size() > 1 ?
+                i18nc("base name of an archive file, e.g. archive.zip or archive.tar.gz", "archive") :
+                firstFile.baseName());
+
+        const auto ad = getDefaultAd();
+        baseNamePgp = baseName + QStringLiteral(".") + ad->extensions(GpgME::OpenPGP).first() + QStringLiteral(".");
+        baseNameCms = baseName + QStringLiteral(".") + ad->extensions(GpgME::CMS).first() + QStringLiteral(".");
+    } else {
+        baseNameCms = baseNamePgp = files.first() + QStringLiteral(".");
+    }
+    const FileOperationsPreferences prefs;
+    const bool ascii = prefs.addASCIIArmor();
+
+    nameMap.insert(SignEncryptFilesWizard::SignatureCMS, baseNameCms + extension(false, true, false, ascii, true));
+    nameMap.insert(SignEncryptFilesWizard::EncryptedCMS, baseNameCms + extension(false, false, true, ascii, false));
+    nameMap.insert(SignEncryptFilesWizard::CombinedPGP,  baseNamePgp + extension(true, true, true, ascii, false));
+    nameMap.insert(SignEncryptFilesWizard::EncryptedPGP, baseNamePgp + extension(true, false, true, ascii, false));
+    nameMap.insert(SignEncryptFilesWizard::SignaturePGP, baseNamePgp + extension(true, true, false, ascii, true));
+    return nameMap;
+}
+
 void SignEncryptFilesController::setFiles(const QStringList &files)
 {
     kleo_assert(!files.empty());
     d->files = files;
-    if (contains_dir(files)) {
+    bool archive = false;
+    if (files.size() > 1 || QFileInfo(files.first()).isDir()) {
         setOperationMode((operationMode() & ~ArchiveMask) | ArchiveForced);
+        archive = true;
     }
     d->ensureWizardCreated();
-    d->wizard->setFiles(files);
+    d->wizard->setOutputNames(buildOutputNames(files, archive));
 }
 
 void SignEncryptFilesController::Private::slotWizardCanceled()
@@ -303,63 +339,60 @@ void SignEncryptFilesController::start()
     d->ensureWizardVisible();
 }
 
-static const char *extension(bool pgp, bool sign, bool encrypt, bool ascii, bool detached)
+static std::shared_ptr<SignEncryptFilesTask>
+createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool ascii,
+                                 const std::vector<Key> &recipients, const std::vector<Key> &signers,
+                                 const QString &outputName, bool symmetric)
 {
-    unsigned int cls = pgp ? Class::OpenPGP : Class::CMS;
-    if (encrypt) {
-        cls |= Class::CipherText;
-    } else if (sign) {
-        cls |= detached ? Class::DetachedSignature : Class::OpaqueSignature;
-    }
-    cls |= ascii ? Class::Ascii : Class::Binary;
-    if (const char *const ext = outputFileExtension(cls)) {
-        return ext;
-    } else {
-        return "out";
-    }
-}
-
-static shared_ptr<SignEncryptFilesTask>
-createSignEncryptTaskForFileInfo(const QFileInfo &fi, bool pgp, bool sign, bool encrypt, bool ascii, const std::vector<Key> &recipients, const std::vector<Key> &signers)
-{
-    const shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
-    task->setSign(sign);
-    task->setEncrypt(encrypt);
+    const std::shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
+    Q_ASSERT(!signers.empty() || !recipients.empty() || symmetric);
     task->setAsciiArmor(ascii);
-    if (sign) {
+    if (!signers.empty()) {
+        task->setSign(true);
         task->setSigners(signers);
         task->setDetachedSignature(true);
+    } else {
+        task->setSign(false);
     }
-    if (encrypt) {
+    if (!recipients.empty()) {
+        task->setEncrypt(true);
         task->setRecipients(recipients);
+        task->setDetachedSignature(false);
+    } else {
+        task->setEncrypt(false);
     }
-
+    task->setEncryptSymmetric(symmetric);
     const QString input = fi.absoluteFilePath();
     task->setInputFileName(input);
     task->setInput(Input::createFromFile(input));
 
-    const char *const ext = extension(pgp, sign, encrypt, ascii, true);
-    kleo_assert(ext);
-
-    const QString output = input + QLatin1Char('.') + QLatin1String(ext);
-    task->setOutputFileName(output);
+    task->setOutputFileName(outputName);
 
     return task;
 }
 
-static shared_ptr<SignEncryptFilesTask>
-createArchiveSignEncryptTaskForFiles(const QStringList &files, const QString &outputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool pgp, bool sign, bool encrypt, bool ascii, const std::vector<Key> &recipients, const std::vector<Key> &signers)
+static std::shared_ptr<SignEncryptFilesTask>
+createArchiveSignEncryptTaskForFiles(const QStringList &files,
+                                     const std::shared_ptr<ArchiveDefinition> &ad, bool pgp, bool ascii,
+                                     const std::vector<Key> &recipients, const std::vector<Key> &signers,
+                                     const QString& outputName, bool symmetric)
 {
-    const shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
-    task->setSign(sign);
-    task->setEncrypt(encrypt);
+    const std::shared_ptr<SignEncryptFilesTask> task(new SignEncryptFilesTask);
+    task->setEncryptSymmetric(symmetric);
+    Q_ASSERT(!signers.empty() || !recipients.empty() || symmetric);
     task->setAsciiArmor(ascii);
-    if (sign) {
+    if (!signers.empty()) {
+        task->setSign(true);
         task->setSigners(signers);
         task->setDetachedSignature(false);
+    } else {
+        task->setSign(false);
     }
-    if (encrypt) {
+    if (!recipients.empty()) {
+        task->setEncrypt(true);
         task->setRecipients(recipients);
+    } else {
+        task->setEncrypt(false);
     }
 
     kleo_assert(ad);
@@ -369,60 +402,90 @@ createArchiveSignEncryptTaskForFiles(const QStringList &files, const QString &ou
     task->setInputFileNames(files);
     task->setInput(ad->createInputFromPackCommand(proto, files));
 
-    const char *const ext = extension(pgp, sign, encrypt, ascii, false);
-    kleo_assert(ext);
-    kleo_assert(!ad->extensions(proto).empty());
-
-    task->setOutputFileName(outputFileBaseName + QLatin1Char('.') + QLatin1String(ext));
+    task->setOutputFileName(outputName);
 
     return task;
 }
 
-static std::vector< shared_ptr<SignEncryptFilesTask> >
-createSignEncryptTasksForFileInfo(const QFileInfo &fi, bool sign, bool encrypt, bool ascii, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
+static std::vector< std::shared_ptr<SignEncryptFilesTask> >
+createSignEncryptTasksForFileInfo(const QFileInfo &fi, bool ascii, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners,
+                                  const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners, const QMap<int, QString> outputNames,
+                                  bool symmetric)
 {
-    std::vector< shared_ptr<SignEncryptFilesTask> > result;
+    std::vector< std::shared_ptr<SignEncryptFilesTask> > result;
 
-    const bool shallPgpSign = sign && !pgpSigners.empty();
-    const bool shallPgpEncrypt = encrypt && !pgpRecipients.empty();
-    const bool pgp = (shallPgpEncrypt && (!sign || shallPgpSign)) || (!encrypt && shallPgpSign);
+    const bool pgp = !pgpSigners.empty() || !pgpRecipients.empty();
 
-    const bool shallCmsSign = sign && !cmsSigners.empty();
-    const bool shallCmsEncrypt = encrypt && !cmsRecipients.empty();
-    const bool cms = (shallCmsEncrypt && (!sign || shallCmsSign)) || (!encrypt && shallCmsSign);
+    const bool cms = !cmsSigners.empty() || !cmsRecipients.empty();
 
     result.reserve(pgp + cms);
 
-    if (pgp) {
-        result.push_back(createSignEncryptTaskForFileInfo(fi, true, sign, encrypt, ascii, pgpRecipients, pgpSigners));
+
+    if (pgp || symmetric) {
+        // Symmetric encryption is only supported for PGP
+        int outKind = 0;
+        if ((!pgpRecipients.empty() || symmetric)&& !pgpSigners.empty()) {
+            outKind = SignEncryptFilesWizard::CombinedPGP;
+        } else if (!pgpRecipients.empty() || symmetric) {
+            outKind = SignEncryptFilesWizard::EncryptedPGP;
+        } else {
+            outKind = SignEncryptFilesWizard::SignaturePGP;
+        }
+        result.push_back(createSignEncryptTaskForFileInfo(fi, ascii, pgpRecipients, pgpSigners, outputNames[outKind], symmetric));
     }
     if (cms) {
-        result.push_back(createSignEncryptTaskForFileInfo(fi, false, sign, encrypt, ascii, cmsRecipients, cmsSigners));
+        // There is no combined sign / encrypt in gpgsm so we create one sign task
+        // and one encrypt task. Which leaves us with the age old dilemma, encrypt
+        // then sign, or sign then encrypt. Ugly.
+        if (!cmsSigners.empty()) {
+            result.push_back(createSignEncryptTaskForFileInfo(fi, ascii, std::vector<Key>(),
+                                                              cmsSigners, outputNames[SignEncryptFilesWizard::SignatureCMS],
+                                                              false));
+        } else {
+            result.push_back(createSignEncryptTaskForFileInfo(fi, ascii, cmsRecipients,
+                                                              std::vector<Key>(), outputNames[SignEncryptFilesWizard::EncryptedCMS],
+                                                              false));
+        }
     }
 
     return result;
 }
 
-static std::vector< shared_ptr<SignEncryptFilesTask> >
-createArchiveSignEncryptTasksForFiles(const QStringList &files, const QString &pgpOutputFileBaseName, const QString &cmsOutputFileBaseName, const shared_ptr<ArchiveDefinition> &ad, bool sign, bool encrypt, bool ascii, const std::vector<Key> &pgpRecipients, const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners)
+static std::vector< std::shared_ptr<SignEncryptFilesTask> >
+createArchiveSignEncryptTasksForFiles(const QStringList &files, const std::shared_ptr<ArchiveDefinition> &ad,
+                                      bool ascii, const std::vector<Key> &pgpRecipients,
+                                      const std::vector<Key> &pgpSigners, const std::vector<Key> &cmsRecipients, const std::vector<Key> &cmsSigners,
+                                      const QMap<int, QString> outputNames, bool symmetric)
 {
-    std::vector< shared_ptr<SignEncryptFilesTask> > result;
+    std::vector< std::shared_ptr<SignEncryptFilesTask> > result;
 
-    const bool shallPgpSign = sign && !pgpSigners.empty();
-    const bool shallPgpEncrypt = encrypt && !pgpRecipients.empty();
-    const bool pgp = (shallPgpEncrypt && (!sign || shallPgpSign)) || (!encrypt && shallPgpSign);
+    const bool pgp = !pgpSigners.empty() || !pgpRecipients.empty();
 
-    const bool shallCmsSign = sign && !cmsSigners.empty();
-    const bool shallCmsEncrypt = encrypt && !cmsRecipients.empty();
-    const bool cms = (shallCmsEncrypt && (!sign || shallCmsSign)) || (!encrypt && shallCmsSign);
+    const bool cms = !cmsSigners.empty() || !cmsRecipients.empty();
 
     result.reserve(pgp + cms);
 
-    if (pgp) {
-        result.push_back(createArchiveSignEncryptTaskForFiles(files, pgpOutputFileBaseName, ad, true,  sign, encrypt, ascii, pgpRecipients, pgpSigners));
+    if (pgp || symmetric) {
+        int outKind = 0;
+        if ((!pgpRecipients.empty() || symmetric) && !pgpSigners.empty()) {
+            outKind = SignEncryptFilesWizard::CombinedPGP;
+        } else if (!pgpRecipients.empty() || symmetric) {
+            outKind = SignEncryptFilesWizard::EncryptedPGP;
+        } else {
+            outKind = SignEncryptFilesWizard::SignaturePGP;
+        }
+        result.push_back(createArchiveSignEncryptTaskForFiles(files, ad, true,  ascii, pgpRecipients, pgpSigners, outputNames[outKind], symmetric));
     }
     if (cms) {
-        result.push_back(createArchiveSignEncryptTaskForFiles(files, cmsOutputFileBaseName, ad, false, sign, encrypt, ascii, cmsRecipients, cmsSigners));
+        if (!cmsSigners.empty()) {
+            result.push_back(createArchiveSignEncryptTaskForFiles(files, ad, false, ascii,
+                                                                  std::vector<Key>(), cmsSigners, outputNames[SignEncryptFilesWizard::SignatureCMS],
+                                                                  false));
+        } else {
+            result.push_back(createArchiveSignEncryptTaskForFiles(files, ad, false, ascii,
+                                                                  cmsRecipients, std::vector<Key>(), outputNames[SignEncryptFilesWizard::EncryptedCMS],
+                                                                  false));
+        }
     }
 
     return result;
@@ -432,60 +495,66 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
 {
 
     try {
-
         kleo_assert(wizard);
         kleo_assert(!files.empty());
 
-        const bool archive = wizard->isCreateArchiveSelected();
+        const bool archive = (operation & ArchiveMask) == ArchiveForced;
 
-        const bool sign = wizard->isSigningSelected();
-        const bool encrypt = wizard->isEncryptionSelected();
+        const QVector<Key> recipients = wizard->resolvedRecipients();
+        const QVector<Key> signers = wizard->resolvedSigners();
 
-        const bool ascii = wizard->isAsciiArmorEnabled();
+        const FileOperationsPreferences prefs;
+        const bool ascii = prefs.addASCIIArmor();
 
-        std::vector<Key> pgpRecipients, cmsRecipients, pgpSigners, cmsSigners;
-        if (encrypt) {
-            const std::vector<Key> recipients = wizard->resolvedRecipients();
-            kdtools::copy_if(recipients.begin(), recipients.end(),
-                             std::back_inserter(pgpRecipients),
-                             boost::bind(&Key::protocol, _1) == GpgME::OpenPGP);
-            kdtools::copy_if(recipients.begin(), recipients.end(),
-                             std::back_inserter(cmsRecipients),
-                             boost::bind(&Key::protocol, _1) == GpgME::CMS);
-            kleo_assert(pgpRecipients.size() + cmsRecipients.size() == recipients.size());
-        }
-        if (sign) {
-            const std::vector<Key> signers = wizard->resolvedSigners();
-            kdtools::copy_if(signers.begin(), signers.end(),
-                             std::back_inserter(pgpSigners),
-                             boost::bind(&Key::protocol, _1) == GpgME::OpenPGP);
-            kdtools::copy_if(signers.begin(), signers.end(),
-                             std::back_inserter(cmsSigners),
-                             boost::bind(&Key::protocol, _1) == GpgME::CMS);
-            kleo_assert(pgpSigners.size() + cmsSigners.size() == signers.size());
+        QVector<Key> pgpRecipients, cmsRecipients, pgpSigners, cmsSigners;
+        Q_FOREACH (const Key k, recipients) {
+            if (k.protocol() == GpgME::OpenPGP) {
+                pgpRecipients << k;
+            } else {
+                cmsRecipients << k;
+            }
         }
 
-        std::vector< shared_ptr<SignEncryptFilesTask> > tasks;
+        Q_FOREACH (Key k, signers) {
+            if (k.protocol() == GpgME::OpenPGP) {
+                pgpSigners << k;
+            } else {
+                cmsSigners << k;
+            }
+        }
+
+        std::vector< std::shared_ptr<SignEncryptFilesTask> > tasks;
         if (!archive) {
             tasks.reserve(files.size());
         }
 
-        if (archive)
+        if (archive) {
             tasks = createArchiveSignEncryptTasksForFiles(files,
-                    wizard->archiveFileName(OpenPGP),
-                    wizard->archiveFileName(CMS),
-                    wizard->selectedArchiveDefinition(),
-                    sign, encrypt, ascii,
-                    pgpRecipients, pgpSigners, cmsRecipients, cmsSigners);
-        else
+                    getDefaultAd(),
+                    ascii,
+                    pgpRecipients.toStdVector(),
+                    pgpSigners.toStdVector(),
+                    cmsRecipients.toStdVector(),
+                    cmsSigners.toStdVector(),
+                    wizard->outputNames(),
+                    wizard->encryptSymmetric());
+
+        } else {
             Q_FOREACH (const QString &file, files) {
-                const std::vector< shared_ptr<SignEncryptFilesTask> > created =
-                    createSignEncryptTasksForFileInfo(QFileInfo(file), sign, encrypt, ascii, pgpRecipients, pgpSigners, cmsRecipients, cmsSigners);
+                const std::vector< std::shared_ptr<SignEncryptFilesTask> > created =
+                    createSignEncryptTasksForFileInfo(QFileInfo(file), ascii,
+                            pgpRecipients.toStdVector(),
+                            pgpSigners.toStdVector(),
+                            cmsRecipients.toStdVector(),
+                            cmsSigners.toStdVector(),
+                            wizard->outputNames(),
+                            wizard->encryptSymmetric());
                 tasks.insert(tasks.end(), created.begin(), created.end());
             }
+        }
 
-        const shared_ptr<OverwritePolicy> overwritePolicy(new OverwritePolicy(wizard));
-        Q_FOREACH (const shared_ptr<SignEncryptFilesTask> &i, tasks) {
+        const std::shared_ptr<OverwritePolicy> overwritePolicy(new OverwritePolicy(wizard));
+        Q_FOREACH (const std::shared_ptr<SignEncryptFilesTask> &i, tasks) {
             i->setOverwritePolicy(overwritePolicy);
         }
 
@@ -493,12 +562,13 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
 
         runnable.swap(tasks);
 
-        Q_FOREACH (const shared_ptr<Task> &task, runnable) {
+        Q_FOREACH (const std::shared_ptr<Task> &task, runnable) {
             q->connectTask(task);
         }
 
-        shared_ptr<TaskCollection> coll(new TaskCollection);
-        std::vector<shared_ptr<Task> > tmp;
+        std::shared_ptr<TaskCollection> coll(new TaskCollection);
+
+        std::vector<std::shared_ptr<Task> > tmp;
         std::copy(runnable.begin(), runnable.end(), std::back_inserter(tmp));
         coll->setTasks(tmp);
         wizard->setTaskCollection(coll);
@@ -521,13 +591,13 @@ void SignEncryptFilesController::Private::schedule()
 {
 
     if (!cms)
-        if (const shared_ptr<SignEncryptFilesTask> t = takeRunnable(CMS)) {
+        if (const std::shared_ptr<SignEncryptFilesTask> t = takeRunnable(CMS)) {
             t->start();
             cms = t;
         }
 
     if (!openpgp)
-        if (const shared_ptr<SignEncryptFilesTask> t = takeRunnable(OpenPGP)) {
+        if (const std::shared_ptr<SignEncryptFilesTask> t = takeRunnable(OpenPGP)) {
             t->start();
             openpgp = t;
         }
@@ -538,21 +608,20 @@ void SignEncryptFilesController::Private::schedule()
     }
 }
 
-shared_ptr<SignEncryptFilesTask> SignEncryptFilesController::Private::takeRunnable(GpgME::Protocol proto)
+std::shared_ptr<SignEncryptFilesTask> SignEncryptFilesController::Private::takeRunnable(GpgME::Protocol proto)
 {
-    const std::vector< shared_ptr<SignEncryptFilesTask> >::iterator it
-        = std::find_if(runnable.begin(), runnable.end(),
-                       boost::bind(&Task::protocol, _1) == proto);
+    const auto it = std::find_if(runnable.begin(), runnable.end(),
+                                 [proto](const std::shared_ptr<Task> &task) { return task->protocol() == proto; });
     if (it == runnable.end()) {
-        return shared_ptr<SignEncryptFilesTask>();
+        return std::shared_ptr<SignEncryptFilesTask>();
     }
 
-    const shared_ptr<SignEncryptFilesTask> result = *it;
+    const std::shared_ptr<SignEncryptFilesTask> result = *it;
     runnable.erase(it);
     return result;
 }
 
-void SignEncryptFilesController::doTaskDone(const Task *task, const shared_ptr<const Task::Result> &result)
+void SignEncryptFilesController::doTaskDone(const Task *task, const std::shared_ptr<const Task::Result> &result)
 {
     Q_UNUSED(result)
     assert(task);
