@@ -40,7 +40,7 @@
 
 #include <gpgme++/global.h>
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 
 namespace Kleo
 {
@@ -73,31 +73,25 @@ public:
     virtual QString tag() const;
 
     QString progressLabel() const;
-    unsigned long long processedSize() const;
-    unsigned long long totalSize() const;
+    int currentProgress() const;
+    int totalProgress() const;
 
     int id() const;
 
-    static boost::shared_ptr<Task> makeErrorTask(int code, const QString &details, const QString &label);
+    static std::shared_ptr<Task> makeErrorTask(int code, const QString &details, const QString &label);
 
 public Q_SLOTS:
     virtual void cancel() = 0;
 
 Q_SIGNALS:
-
-#ifndef Q_MOC_RUN
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-private: // don't tell moc, but those signals are in fact private
-#endif
-#endif
-    void progress(const QString &what, int processed, int total);
-    void result(const boost::shared_ptr<const Kleo::Crypto::Task::Result> &);
-    void started();
+    void progress(const QString &what, int processed, int total, QPrivateSignal);
+    void result(const std::shared_ptr<const Kleo::Crypto::Task::Result> &, QPrivateSignal);
+    void started(QPrivateSignal);
 
 protected:
-    boost::shared_ptr<Result> makeErrorResult(int errCode, const QString &details);
+    std::shared_ptr<Result> makeErrorResult(int errCode, const QString &details);
 
-    void emitResult(const boost::shared_ptr<const Task::Result> &result);
+    void emitResult(const std::shared_ptr<const Task::Result> &result);
 
 protected Q_SLOTS:
     void setProgress(const QString &msg, int processed, int total);
