@@ -41,14 +41,15 @@
 #include <conf/configuredialog.h>
 
 #include <utils/gnupg-helper.h>
-#include <utils/filesystemwatcher.h>
 #include <utils/kdpipeiodevice.h>
 #include <utils/log.h>
 #include <utils/getpid.h>
-#include "utils/classify.h"
 
 #include <gpgme++/key.h>
-#include <models/keycache.h>
+
+#include <Libkleo/FileSystemWatcher>
+#include <Libkleo/KeyCache>
+#include <Libkleo/Classify>
 
 #ifdef HAVE_USABLE_ASSUAN
 # include <uiserver/uiserver.h>
@@ -60,6 +61,7 @@
 #include "commands/checksumcreatefilescommand.h"
 #include "commands/checksumverifyfilescommand.h"
 #include "commands/detailscommand.h"
+#include "commands/newcertificatecommand.h"
 
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -73,14 +75,11 @@
 #include <QPointer>
 #include <QCommandLineOption>
 
-#include <boost/shared_ptr.hpp>
-
 #include <memory>
 #include <KSharedConfig>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
-using namespace boost;
 
 static void add_resources()
 {
@@ -103,18 +102,23 @@ public:
     explicit Private(KleopatraApplication *qq)
         : q(qq),
           ignoreNewInstance(true)
+    {
+    }
+    ~Private() {
+        delete sysTray;
+    }
+    void init()
     {
         KDAB_SET_OBJECT_NAME(readerStatus);
 #ifndef QT_NO_SYSTEMTRAYICON
-        KDAB_SET_OBJECT_NAME(sysTray);
-
-        sysTray.setAnyCardHasNullPin(readerStatus.anyCardHasNullPin());
-        sysTray.setAnyCardCanLearnKeys(readerStatus.anyCardCanLearnKeys());
+        sysTray = new SysTrayIcon();
+        sysTray->setAnyCardHasNullPin(readerStatus.anyCardHasNullPin());
+        sysTray->setAnyCardCanLearnKeys(readerStatus.anyCardCanLearnKeys());
 
         connect(&readerStatus, &SmartCard::ReaderStatus::anyCardHasNullPinChanged,
-                &sysTray, &SysTrayIcon::setAnyCardHasNullPin);
+                sysTray, &SysTrayIcon::setAnyCardHasNullPin);
         connect(&readerStatus, &SmartCard::ReaderStatus::anyCardCanLearnKeysChanged,
-                &sysTray, &SysTrayIcon::setAnyCardCanLearnKeys);
+                sysTray, &SysTrayIcon::setAnyCardCanLearnKeys);
 #endif
     }
 
@@ -138,11 +142,11 @@ public:
     QPointer<MainWindow> mainWindow;
     SmartCard::ReaderStatus readerStatus;
 #ifndef QT_NO_SYSTEMTRAYICON
-    SysTrayIcon sysTray;
+    SysTrayIcon *sysTray;
 #endif
-    shared_ptr<KeyCache> keyCache;
-    shared_ptr<Log> log;
-    shared_ptr<FileSystemWatcher> watcher;
+    std::shared_ptr<KeyCache> keyCache;
+    std::shared_ptr<Log> log;
+    std::shared_ptr<FileSystemWatcher> watcher;
 
 public:
     void setupKeyCache()
@@ -195,11 +199,16 @@ public:
 KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
     : QApplication(argc, argv), d(new Private(this))
 {
+}
+
+void KleopatraApplication::init()
+{
+    d->init();
     add_resources();
     d->setupKeyCache();
     d->setupLogging();
 #ifndef QT_NO_SYSTEMTRAYICON
-    d->sysTray.show();
+    d->sysTray->show();
 #endif
     setQuitOnLastWindowClosed(false);
     KWindowSystem::allowExternalProcessWindowActivation();
@@ -320,6 +329,15 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
         return QString();
     }
 
+    // Check for --gen-key command
+    if (parser.isSet("gen-key")) {
+        auto cmd = new NewCertificateCommand(Q_NULLPTR);
+        cmd->setParentWId(parentId);
+        cmd->setProtocol(protocol);
+        cmd->start();
+        return QString();
+    }
+
     static const QMap<QString, Func> funcMap {
         { QStringLiteral("import-certificate"), &KleopatraApplication::importCertificatesFromFile },
         { QStringLiteral("encrypt"), &KleopatraApplication::encryptFiles },
@@ -375,12 +393,12 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
 #ifndef QT_NO_SYSTEMTRAYICON
 const SysTrayIcon *KleopatraApplication::sysTrayIcon() const
 {
-    return &d->sysTray;
+    return d->sysTray;
 }
 
 SysTrayIcon *KleopatraApplication::sysTrayIcon()
 {
-    return &d->sysTray;
+    return d->sysTray;
 }
 #endif
 
@@ -404,7 +422,7 @@ void KleopatraApplication::setMainWindow(MainWindow *mainWindow)
 
     d->mainWindow = mainWindow;
 #ifndef QT_NO_SYSTEMTRAYICON
-    d->sysTray.setMainWindow(mainWindow);
+    d->sysTray->setMainWindow(mainWindow);
 #endif
 
     d->connectConfigureDialog();
