@@ -35,13 +35,11 @@
 #include "readerstatus.h"
 
 #include <utils/gnupg-helper.h>
-#include <utils/kdsignalblocker.h>
-#include <utils/filesystemwatcher.h>
 
+#include <Libkleo/FileSystemWatcher>
 #include <Libkleo/Stl_Util>
 
 #include <gpgme++/context.h>
-#include <gpgme++/assuanresult.h>
 #include <gpgme++/defaultassuantransaction.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
@@ -61,11 +59,8 @@
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
-#include <boost/static_assert.hpp>
-#include <boost/range.hpp>
-#include <boost/bind.hpp>
-#include <boost/shared_ptr.hpp>
 
+#include <memory>
 #include <vector>
 #include <set>
 #include <list>
@@ -77,7 +72,6 @@
 using namespace Kleo;
 using namespace Kleo::SmartCard;
 using namespace GpgME;
-using namespace boost;
 
 static const unsigned int CHECK_INTERVAL = 2000; // msecs
 
@@ -115,7 +109,7 @@ static const char *flags[] = {
     "ACTIVE",
     "USABLE",
 };
-BOOST_STATIC_ASSERT((sizeof flags / sizeof * flags == ReaderStatus::_NumScdStates));
+static_assert(sizeof flags / sizeof * flags == ReaderStatus::_NumScdStates, "");
 
 static const char *prettyFlags[] = {
     "NoCard",
@@ -126,7 +120,7 @@ static const char *prettyFlags[] = {
     "CardHasNullPin",
     "CardError",
 };
-BOOST_STATIC_ASSERT((sizeof prettyFlags / sizeof * prettyFlags == ReaderStatus::NumStates));
+static_assert(sizeof prettyFlags / sizeof * prettyFlags == ReaderStatus::NumStates, "");
 
 static QByteArray read_file(const QString &fileName)
 {
@@ -156,17 +150,6 @@ static unsigned int parseFileName(const QString &fileName, bool *ok)
 
 namespace
 {
-template <typename T_Target, typename T_Source>
-std::auto_ptr<T_Target> dynamic_pointer_cast(std::auto_ptr<T_Source> &in)
-{
-    if (T_Target *const target = dynamic_cast<T_Target *>(in.get())) {
-        in.release();
-        return std::auto_ptr<T_Target>(target);
-    } else {
-        return std::auto_ptr<T_Target>();
-    }
-}
-
 template <typename T>
 const T &_trace__impl(const T &t, const char *msg)
 {
@@ -194,16 +177,19 @@ static const char *app_types[] = {
     "dinsig",
     "geldkarte",
 };
-BOOST_STATIC_ASSERT((sizeof app_types / sizeof * app_types == ReaderStatus::NumAppTypes));
+static_assert(sizeof app_types / sizeof * app_types == ReaderStatus::NumAppTypes, "");
 
 static ReaderStatus::AppType parse_app_type(const std::string &s)
 {
     qCDebug(KLEOPATRA_LOG) << "parse_app_type(" << s.c_str() << ")";
-    const char **it = std::find(begin(app_types), end(app_types), to_lower_copy(s));
-    if (it == end(app_types)) {
+    const char **it = std::find_if(std::begin(app_types), std::end(app_types),
+                                [&s](const char *type) {
+                                    return ::strcasecmp(s.c_str(), type) == 0;
+                                });
+    if (it == std::end(app_types)) {
         return TRACE(ReaderStatus::UnknownApplication);
     }
-    return TRACE(static_cast<ReaderStatus::AppType>(it - begin(app_types)));
+    return TRACE(static_cast<ReaderStatus::AppType>(it - std::begin(app_types)));
 
 }
 
@@ -228,16 +214,12 @@ static ReaderStatus::PinState parse_pin_state(const std::string &s)
     }
 }
 
-static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact(shared_ptr<Context> &gpgAgent, const char *command, Error &err)
+static std::unique_ptr<DefaultAssuanTransaction> gpgagent_transact(std::shared_ptr<Context> &gpgAgent, const char *command, Error &err)
 {
 #ifdef DEBUG_SCREADER
     qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << ")";
 #endif
-    const AssuanResult res = gpgAgent->assuanTransact(command);
-    err = res.error();
-    if (!err.code()) {
-        err = res.assuanError();
-    }
+    err = gpgAgent->assuanTransact(command);
     if (err.code()) {
 #ifdef DEBUG_SCREADER
         qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << "):" << QString::fromLocal8Bit(err.asString());
@@ -246,18 +228,18 @@ static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact(shared_ptr<Cont
             qCDebug(KLEOPATRA_LOG) << "Assuan problem, killing context";
             gpgAgent.reset();
         }
-        return std::auto_ptr<DefaultAssuanTransaction>();
+        return std::unique_ptr<DefaultAssuanTransaction>();
     }
-    std::auto_ptr<AssuanTransaction> t = gpgAgent->takeLastAssuanTransaction();
-    return dynamic_pointer_cast<DefaultAssuanTransaction>(t);
+    std::unique_ptr<AssuanTransaction> t = gpgAgent->takeLastAssuanTransaction();
+    return std::unique_ptr<DefaultAssuanTransaction>(dynamic_cast<DefaultAssuanTransaction*>(t.release()));
 }
 
 // returns const std::string so template deduction in boost::split works, and we don't need a temporary
-static const std::string scd_getattr_status(shared_ptr<Context> &gpgAgent, const char *what, Error &err)
+static const std::string scd_getattr_status(std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
 {
     std::string cmd = "SCD GETATTR ";
     cmd += what;
-    const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, cmd.c_str(), err);
+    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, cmd.c_str(), err);
     if (t.get()) {
         qCDebug(KLEOPATRA_LOG) << "scd_getattr_status(" << what << "): got" << t->statusLines();
         return t->firstStatusLine(what);
@@ -276,10 +258,10 @@ static unsigned int parse_event_counter(const std::string &str)
     return -1;
 }
 
-static unsigned int get_event_counter(shared_ptr<Context> &gpgAgent)
+static unsigned int get_event_counter(std::shared_ptr<Context> &gpgAgent)
 {
     Error err;
-    const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, "GETEVENTCOUNTER", err);
+    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, "GETEVENTCOUNTER", err);
     if (err.code()) {
         qCDebug(KLEOPATRA_LOG) << "get_event_counter(): got error" << err.asString();
     }
@@ -295,9 +277,9 @@ static unsigned int get_event_counter(shared_ptr<Context> &gpgAgent)
 }
 
 // returns const std::string so template deduction in boost::split works, and we don't need a temporary
-static const std::string gpgagent_data(shared_ptr<Context> &gpgAgent, const char *what, Error &err)
+static const std::string gpgagent_data(std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
 {
-    const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, what, err);
+    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, what, err);
     if (t.get()) {
         return t->data();
     } else {
@@ -329,7 +311,7 @@ static bool parse_keypairinfo_and_lookup_key(Context *ctx, const std::string &kp
     return !e && !key.isNull();
 }
 
-static CardInfo get_card_status(const QString &fileName, unsigned int idx, shared_ptr<Context> &gpg_agent)
+static CardInfo get_card_status(const QString &fileName, unsigned int idx, std::shared_ptr<Context> &gpg_agent)
 {
 #ifdef DEBUG_SCREADER
     qCDebug(KLEOPATRA_LOG) << "get_card_status(" << fileName << ',' << idx << ',' << gpg_agent.get() << ')';
@@ -368,7 +350,7 @@ static CardInfo get_card_status(const QString &fileName, unsigned int idx, share
     // the following only works for NKS v3...
     std::vector<std::string> chvStatus;
     chvStatus.reserve(4);   // expected number of fields
-    split(chvStatus, scd_getattr_status(gpg_agent, "CHV-STATUS", err), is_any_of(" \t"), token_compress_on);
+    boost::split(chvStatus, scd_getattr_status(gpg_agent, "CHV-STATUS", err), boost::is_any_of(" \t"), boost::token_compress_on);
     if (err.code()) {
         return ci;
     }
@@ -376,13 +358,13 @@ static CardInfo get_card_status(const QString &fileName, unsigned int idx, share
                    std::back_inserter(ci.pinStates),
                    parse_pin_state);
 
-    if (kdtools::contains(ci.pinStates, ReaderStatus::NullPin)) {
+    if (std::find(ci.pinStates.cbegin(), ci.pinStates.cend(), ReaderStatus::NullPin) != ci.pinStates.cend()) {
         ci.status = ReaderStatus::CardHasNullPin;
         return ci;
     }
 
     // check for keys to learn:
-    const std::auto_ptr<DefaultAssuanTransaction> result = gpgagent_transact(gpg_agent, "SCD LEARN --keypairinfo", err);
+    const std::unique_ptr<DefaultAssuanTransaction> result = gpgagent_transact(gpg_agent, "SCD LEARN --keypairinfo", err);
     if (err.code() || !result.get()) {
         return ci;
     }
@@ -392,13 +374,16 @@ static CardInfo get_card_status(const QString &fileName, unsigned int idx, share
     }
 
     // check that any of the
-    const std::auto_ptr<Context> klc(Context::createForProtocol(CMS));     // what about OpenPGP?
+    const std::unique_ptr<Context> klc(Context::createForProtocol(CMS));     // what about OpenPGP?
     if (!klc.get()) {
         return ci;
     }
     klc->setKeyListMode(Ephemeral);
 
-    if (kdtools::any(keyPairInfos, !boost::bind(&parse_keypairinfo_and_lookup_key, klc.get(), _1))) {
+    if (std::any_of(keyPairInfos.cbegin(), keyPairInfos.cend(),
+                    [&klc](const std::string &str) {
+                        return !parse_keypairinfo_and_lookup_key(klc.get(), str);
+                    })) {
         ci.status = ReaderStatus::CardCanLearnKeys;
     }
 
@@ -409,7 +394,7 @@ static CardInfo get_card_status(const QString &fileName, unsigned int idx, share
     return ci;
 }
 
-static std::vector<CardInfo> update_cardinfo(const QString &gnupgHomePath, shared_ptr<Context> &gpgAgent)
+static std::vector<CardInfo> update_cardinfo(const QString &gnupgHomePath, std::shared_ptr<Context> &gpgAgent)
 {
 #ifdef DEBUG_SCREADER
     qCDebug(KLEOPATRA_LOG) << "<update_cardinfo>";
@@ -426,7 +411,7 @@ static std::vector<CardInfo> update_cardinfo(const QString &gnupgHomePath, share
     return std::vector<CardInfo>(1, ci);
 }
 
-static bool check_event_counter_changed(shared_ptr<Context> &gpg_agent, unsigned int &counter)
+static bool check_event_counter_changed(std::shared_ptr<Context> &gpg_agent, unsigned int &counter)
 {
     const unsigned int oldCounter = counter;
     counter = get_event_counter(gpg_agent);
@@ -521,8 +506,10 @@ public Q_SLOTS:
         }
 
         QStringList files = gnupgHome.entryList(QStringList(QStringLiteral("reader_*.status")), QDir::Files, QDir::Name);
-        bool *dummy = 0;
-        kdtools::sort(files, boost::bind(parseFileName, _1, dummy) < boost::bind(parseFileName, _2, dummy));
+        std::sort(files.begin(), files.end(),
+                  [](const QString &lhs, const QString &rhs) {
+                      return parseFileName(lhs, Q_NULLPTR) < parseFileName(rhs, Q_NULLPTR);
+                  });
 
         std::vector<QByteArray> contents;
 
@@ -565,7 +552,7 @@ private Q_SLOTS:
 private:
     void run() Q_DECL_OVERRIDE {
 
-        shared_ptr<Context> gpgAgent;
+        std::shared_ptr<Context> gpgAgent;
         unsigned int eventCounter = -1;
 
         while (true)
@@ -578,11 +565,11 @@ private:
 
             if (!gpgAgent) {
                 Error err;
-                std::auto_ptr<Context> c = Context::createForEngine(AssuanEngine, &err);
+                std::unique_ptr<Context> c = Context::createForEngine(AssuanEngine, &err);
                 if (err.code() == GPG_ERR_NOT_SUPPORTED) {
                     return;
                 }
-                gpgAgent = c;
+                gpgAgent = std::shared_ptr<Context>(c.release());
             }
 
             KDAB_SYNCHRONIZED(m_mutex) {
@@ -753,12 +740,16 @@ public:
 private:
     bool anyCardHasNullPinImpl() const
     {
-        return kdtools::any(cardInfos(), boost::bind(&CardInfo::status, _1) == CardHasNullPin);
+        const auto cis = cardInfos();
+        return std::any_of(cis.cbegin(), cis.cend(),
+                           [](const CardInfo &ci) { return ci.status == CardHasNullPin; });
     }
 
     bool anyCardCanLearnKeysImpl() const
     {
-        return kdtools::any(cardInfos(), boost::bind(&CardInfo::status, _1) == CardCanLearnKeys);
+        const auto cis = cardInfos();
+        return std::any_of(cis.cbegin(), cis.cend(),
+                           [](const CardInfo &ci) { return ci.status == CardCanLearnKeys; });
     }
 
 private:
